Command Line Interface — wordle-game 0.1 documentation

# Command Line Interface

    usage: wordle_game [-h] {play,assistant} ...

## Sub-commands:

### play

You can use this to play wordle games.

    wordle_game play [-h]

### assistant

You can use this to assist you in external wordle games.

    wordle_game assistant [-h] [--solver {random,maxentropy}]

#### Named Arguments

`--solver`

  Possible choices: random, maxentropy

  Solver to use.

  Default: “random”

previous

Welcome to wordle-game’s documentation!

next

Wordle